@@ -18,8 +18,6 @@ from .catalog import catalog
 
 from .ai_audio import ai_audio
 
-from .editor import editor
-
 from .contributors import contributors
 
 from .user import user
@@ -49,8 +47,6 @@ cli.add_command(catalog)
 
 cli.add_command(ai_audio)
 
-cli.add_command(editor)
-
 cli.add_command(contributors)
 
 cli.add_command(user)
